@@ -19,13 +19,16 @@ Checksum::Checksum(checksumtypes type)
   : m_checksumtype(type)
 {
   switch (m_checksumtype) {
-    case SHA1: {
+    case checksumtypes::SHA1: {
       sha1_init(&m_state.sha1);
     } break;
-    case SHA256: {
+    case checksumtypes::SHA256: {
       sha256_init(&m_state.sha256);
     } break;
-    case MD5: {
+    case checksumtypes::SHA512: {
+      sha512_init(&m_state.sha512);
+    } break;
+    case checksumtypes::MD5: {
       md5_init(&m_state.md5);
     } break;
     default:
@@ -38,13 +41,16 @@ int
 Checksum::update(std::size_t length, const unsigned char* buffer)
 {
   switch (m_checksumtype) {
-    case SHA1:
+    case checksumtypes::SHA1:
       sha1_update(&m_state.sha1, length, buffer);
       break;
-    case SHA256:
+    case checksumtypes::SHA256:
       sha256_update(&m_state.sha256, length, buffer);
       break;
-    case MD5:
+    case checksumtypes::SHA512:
+      sha512_update(&m_state.sha512, length, buffer);
+      break;
+    case checksumtypes::MD5:
       md5_update(&m_state.md5, length, buffer);
       break;
     default:
@@ -103,11 +109,13 @@ int
 Checksum::getDigestLength() const
 {
   switch (m_checksumtype) {
-    case SHA1:
+    case checksumtypes::SHA1:
       return SHA1_DIGEST_SIZE;
-    case SHA256:
+    case checksumtypes::SHA256:
       return SHA256_DIGEST_SIZE;
-    case MD5:
+    case checksumtypes::SHA512:
+      return SHA512_DIGEST_SIZE;
+    case checksumtypes::MD5:
       return MD5_DIGEST_SIZE;
     default:
       return -1;
@@ -122,7 +130,7 @@ Checksum::printToBuffer(void* buffer, std::size_t N)
   assert(buffer);
 
   switch (m_checksumtype) {
-    case SHA1:
+    case checksumtypes::SHA1:
       if (N >= SHA1_DIGEST_SIZE) {
         sha1_digest(
           &m_state.sha1, SHA1_DIGEST_SIZE, static_cast<unsigned char*>(buffer));
@@ -131,7 +139,7 @@ Checksum::printToBuffer(void* buffer, std::size_t N)
         return -1;
       }
       break;
-    case SHA256:
+    case checksumtypes::SHA256:
       if (N >= SHA256_DIGEST_SIZE) {
         sha256_digest(&m_state.sha256,
                       SHA256_DIGEST_SIZE,
@@ -141,7 +149,17 @@ Checksum::printToBuffer(void* buffer, std::size_t N)
         return -1;
       }
       break;
-    case MD5:
+    case checksumtypes::SHA512:
+      if (N >= SHA512_DIGEST_SIZE) {
+        sha512_digest(&m_state.sha512,
+                      SHA512_DIGEST_SIZE,
+                      static_cast<unsigned char*>(buffer));
+      } else {
+        // bad size.
+        return -1;
+      }
+      break;
+    case checksumtypes::MD5:
       if (N >= MD5_DIGEST_SIZE) {
         md5_digest(
           &m_state.md5, MD5_DIGEST_SIZE, static_cast<unsigned char*>(buffer));
